Struct vortex_common::msg::ContractOrderResult
source · pub struct ContractOrderResult {
pub contract_address: String,
pub order_placement_results: Vec<OrderPlacementResult>,
pub order_execution_results: Vec<OrderExecutionResult>,
}Fields
contract_address: Stringorder_placement_results: Vec<OrderPlacementResult>order_execution_results: Vec<OrderExecutionResult>Trait Implementations
sourceimpl Clone for ContractOrderResult
impl Clone for ContractOrderResult
sourcefn clone(&self) -> ContractOrderResult
fn clone(&self) -> ContractOrderResult
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ContractOrderResult
impl Debug for ContractOrderResult
sourceimpl<'de> Deserialize<'de> for ContractOrderResult
impl<'de> Deserialize<'de> for ContractOrderResult
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ContractOrderResult
impl JsonSchema for ContractOrderResult
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<ContractOrderResult> for ContractOrderResult
impl PartialEq<ContractOrderResult> for ContractOrderResult
sourcefn eq(&self, other: &ContractOrderResult) -> bool
fn eq(&self, other: &ContractOrderResult) -> bool
This method tests for
self and other values to be equal, and is used
by ==.