Struct vortex_common::msg::GetConfigResponse
source · pub struct GetConfigResponse {
pub admin: String,
pub whitelist: HashSet<Addr>,
pub use_whitelist: bool,
pub limit_order_fee: SignedDecimal,
pub market_order_fee: SignedDecimal,
pub liquidation_order_fee: SignedDecimal,
pub default_margin_ratios: MarginRatios,
pub max_leverage: SignedDecimal,
pub spot_market_contract: String,
}Fields
admin: Stringwhitelist: HashSet<Addr>use_whitelist: boollimit_order_fee: SignedDecimalmarket_order_fee: SignedDecimalliquidation_order_fee: SignedDecimaldefault_margin_ratios: MarginRatiosmax_leverage: SignedDecimalspot_market_contract: StringTrait Implementations
sourceimpl Clone for GetConfigResponse
impl Clone for GetConfigResponse
sourcefn clone(&self) -> GetConfigResponse
fn clone(&self) -> GetConfigResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for GetConfigResponse
impl<'de> Deserialize<'de> for GetConfigResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetConfigResponse
impl JsonSchema for GetConfigResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<GetConfigResponse> for GetConfigResponse
impl PartialEq<GetConfigResponse> for GetConfigResponse
sourcefn eq(&self, other: &GetConfigResponse) -> bool
fn eq(&self, other: &GetConfigResponse) -> bool
This method tests for
self and other values to be equal, and is used
by ==.