pub struct GetCumulativeFundingRateResponse {
pub price_diff: SignedDecimal,
}Fields
price_diff: SignedDecimalTrait Implementations
sourceimpl Clone for GetCumulativeFundingRateResponse
impl Clone for GetCumulativeFundingRateResponse
sourcefn clone(&self) -> GetCumulativeFundingRateResponse
fn clone(&self) -> GetCumulativeFundingRateResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for GetCumulativeFundingRateResponse
impl<'de> Deserialize<'de> for GetCumulativeFundingRateResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetCumulativeFundingRateResponse
impl JsonSchema for GetCumulativeFundingRateResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<GetCumulativeFundingRateResponse> for GetCumulativeFundingRateResponse
impl PartialEq<GetCumulativeFundingRateResponse> for GetCumulativeFundingRateResponse
sourcefn eq(&self, other: &GetCumulativeFundingRateResponse) -> bool
fn eq(&self, other: &GetCumulativeFundingRateResponse) -> bool
This method tests for
self and other values to be equal, and is used
by ==.