Struct vortex_common::msg::GetOrderEstimateResponse
source · pub struct GetOrderEstimateResponse {
pub order_fee_estimate: SignedDecimal,
pub deposits_required: Coin,
}Fields
order_fee_estimate: SignedDecimaldeposits_required: CoinTrait Implementations
sourceimpl Clone for GetOrderEstimateResponse
impl Clone for GetOrderEstimateResponse
sourcefn clone(&self) -> GetOrderEstimateResponse
fn clone(&self) -> GetOrderEstimateResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for GetOrderEstimateResponse
impl<'de> Deserialize<'de> for GetOrderEstimateResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetOrderEstimateResponse
impl JsonSchema for GetOrderEstimateResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<GetOrderEstimateResponse> for GetOrderEstimateResponse
impl PartialEq<GetOrderEstimateResponse> for GetOrderEstimateResponse
sourcefn eq(&self, other: &GetOrderEstimateResponse) -> bool
fn eq(&self, other: &GetOrderEstimateResponse) -> bool
This method tests for
self and other values to be equal, and is used
by ==.