Struct vortex_common::msg::GetPortfolioSpecsResponse
source · pub struct GetPortfolioSpecsResponse {
pub equity: SignedDecimal,
pub total_position_value: SignedDecimal,
pub buying_power: SignedDecimal,
pub unrealized_pnl: SignedDecimal,
pub leverage: SignedDecimal,
pub balance: SignedDecimal,
}Fields
equity: SignedDecimaltotal_position_value: SignedDecimalbuying_power: SignedDecimalunrealized_pnl: SignedDecimalleverage: SignedDecimalbalance: SignedDecimalTrait Implementations
sourceimpl Clone for GetPortfolioSpecsResponse
impl Clone for GetPortfolioSpecsResponse
sourcefn clone(&self) -> GetPortfolioSpecsResponse
fn clone(&self) -> GetPortfolioSpecsResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for GetPortfolioSpecsResponse
impl Debug for GetPortfolioSpecsResponse
sourceimpl<'de> Deserialize<'de> for GetPortfolioSpecsResponse
impl<'de> Deserialize<'de> for GetPortfolioSpecsResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetPortfolioSpecsResponse
impl JsonSchema for GetPortfolioSpecsResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<GetPortfolioSpecsResponse> for GetPortfolioSpecsResponse
impl PartialEq<GetPortfolioSpecsResponse> for GetPortfolioSpecsResponse
sourcefn eq(&self, other: &GetPortfolioSpecsResponse) -> bool
fn eq(&self, other: &GetPortfolioSpecsResponse) -> bool
This method tests for
self and other values to be equal, and is used
by ==.