Struct vortex_common::msg::GetPositionResponse
source · pub struct GetPositionResponse {
pub long_position: SignedDecimal,
pub long_position_margin_debt: SignedDecimal,
pub long_position_last_funding_payment_epoch: i64,
pub long_position_pnl: SignedDecimal,
pub short_position: SignedDecimal,
pub short_position_margin_debt: SignedDecimal,
pub short_position_last_funding_payment_epoch: i64,
pub short_position_pnl: SignedDecimal,
}Fields
long_position: SignedDecimallong_position_margin_debt: SignedDecimallong_position_last_funding_payment_epoch: i64long_position_pnl: SignedDecimalshort_position: SignedDecimalshort_position_margin_debt: SignedDecimalshort_position_last_funding_payment_epoch: i64short_position_pnl: SignedDecimalTrait Implementations
sourceimpl Clone for GetPositionResponse
impl Clone for GetPositionResponse
sourcefn clone(&self) -> GetPositionResponse
fn clone(&self) -> GetPositionResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for GetPositionResponse
impl<'de> Deserialize<'de> for GetPositionResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for GetPositionResponse
impl JsonSchema for GetPositionResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<GetPositionResponse> for GetPositionResponse
impl PartialEq<GetPositionResponse> for GetPositionResponse
sourcefn eq(&self, other: &GetPositionResponse) -> bool
fn eq(&self, other: &GetPositionResponse) -> bool
This method tests for
self and other values to be equal, and is used
by ==.