Struct vortex_common::msg::InstantiateMsg
source · pub struct InstantiateMsg {Show 20 fields
pub whitelist: Vec<String>,
pub denoms: Vec<String>,
pub supported_collateral_denoms: Vec<String>,
pub supported_multicollateral_denoms: Vec<String>,
pub full_denom_mapping: Vec<(String, String, Decimal)>,
pub oracle_denom_mapping: Vec<(String, String, Decimal)>,
pub use_whitelist: bool,
pub multicollateral_whitelist: Vec<Addr>,
pub multicollateral_whitelist_enable: bool,
pub admin: String,
pub limit_order_fee: SignedDecimal,
pub market_order_fee: SignedDecimal,
pub liquidation_order_fee: SignedDecimal,
pub max_leverage: SignedDecimal,
pub funding_payment_lookback: u64,
pub native_token: String,
pub default_base: String,
pub spot_market_contract: Addr,
pub funding_payment_pairs: Vec<(String, String)>,
pub default_margin_ratios: MarginRatios,
}Fields
whitelist: Vec<String>denoms: Vec<String>supported_collateral_denoms: Vec<String>supported_multicollateral_denoms: Vec<String>full_denom_mapping: Vec<(String, String, Decimal)>oracle_denom_mapping: Vec<(String, String, Decimal)>use_whitelist: boolmulticollateral_whitelist: Vec<Addr>multicollateral_whitelist_enable: booladmin: Stringlimit_order_fee: SignedDecimalmarket_order_fee: SignedDecimalliquidation_order_fee: SignedDecimalmax_leverage: SignedDecimalfunding_payment_lookback: u64native_token: Stringdefault_base: Stringspot_market_contract: Addrfunding_payment_pairs: Vec<(String, String)>default_margin_ratios: MarginRatiosTrait Implementations
sourceimpl Clone for InstantiateMsg
impl Clone for InstantiateMsg
sourcefn clone(&self) -> InstantiateMsg
fn clone(&self) -> InstantiateMsg
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for InstantiateMsg
impl Debug for InstantiateMsg
sourceimpl<'de> Deserialize<'de> for InstantiateMsg
impl<'de> Deserialize<'de> for InstantiateMsg
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for InstantiateMsg
impl JsonSchema for InstantiateMsg
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<InstantiateMsg> for InstantiateMsg
impl PartialEq<InstantiateMsg> for InstantiateMsg
sourcefn eq(&self, other: &InstantiateMsg) -> bool
fn eq(&self, other: &InstantiateMsg) -> bool
This method tests for
self and other values to be equal, and is used
by ==.