Struct vortex_common::msg::SettlementEntry
source · pub struct SettlementEntry {
pub account: String,
pub price_denom: String,
pub asset_denom: String,
pub quantity: Decimal,
pub execution_cost_or_proceed: Decimal,
pub expected_cost_or_proceed: Decimal,
pub position_direction: PositionDirection,
pub order_type: OrderType,
pub order_id: u64,
}Fields
account: Stringprice_denom: Stringasset_denom: Stringquantity: Decimalexecution_cost_or_proceed: Decimalexpected_cost_or_proceed: Decimalposition_direction: PositionDirectionorder_type: OrderTypeorder_id: u64Trait Implementations
sourceimpl Clone for SettlementEntry
impl Clone for SettlementEntry
sourcefn clone(&self) -> SettlementEntry
fn clone(&self) -> SettlementEntry
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SettlementEntry
impl Debug for SettlementEntry
sourceimpl<'de> Deserialize<'de> for SettlementEntry
impl<'de> Deserialize<'de> for SettlementEntry
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for SettlementEntry
impl JsonSchema for SettlementEntry
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<SettlementEntry> for SettlementEntry
impl PartialEq<SettlementEntry> for SettlementEntry
sourcefn eq(&self, other: &SettlementEntry) -> bool
fn eq(&self, other: &SettlementEntry) -> bool
This method tests for
self and other values to be equal, and is used
by ==.