Struct vortex_common::types::MarginRatios
source · [−]Fields
initial: Decimalpartial: Decimalmaintenance: DecimalTrait Implementations
sourceimpl Clone for MarginRatios
impl Clone for MarginRatios
sourcefn clone(&self) -> MarginRatios
fn clone(&self) -> MarginRatios
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for MarginRatios
impl Debug for MarginRatios
sourceimpl<'de> Deserialize<'de> for MarginRatios
impl<'de> Deserialize<'de> for MarginRatios
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for MarginRatios
impl JsonSchema for MarginRatios
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<MarginRatios> for MarginRatios
impl PartialEq<MarginRatios> for MarginRatios
sourcefn eq(&self, other: &MarginRatios) -> bool
fn eq(&self, other: &MarginRatios) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &MarginRatios) -> bool
fn ne(&self, other: &MarginRatios) -> bool
This method tests for !=.
sourceimpl Serialize for MarginRatios
impl Serialize for MarginRatios
impl StructuralPartialEq for MarginRatios